"use client";

import Image from "next/image";
import { useEffect, useState } from "react";

import { motion } from "framer-motion";

import { cn } from "@/lib/utils";

let interval: any;

type Card = {
	id: number;
	name?: string;
	designation?: string;
	content?: React.ReactNode;
	imageUrl?: string;
	imageWidth?: number;
	imageHeight?: number;
	className?: string;
};

export const CardStack = ({
	items,
	offset,
	scaleFactor,
}: {
	items: Card[];
	offset?: number;
	scaleFactor?: number;
}) => {
	const CARD_OFFSET = offset || 10;
	const SCALE_FACTOR = scaleFactor || 0.06;
	const [cards, setCards] = useState<Card[]>(items);

	useEffect(() => {
		startFlipping();

		return () => clearInterval(interval);
	}, []);

	const startFlipping = () => {
		interval = setInterval(() => {
			setCards((prevCards: Card[]) => {
				const newArray = [...prevCards]; // create a copy of the array
				newArray.unshift(newArray.pop()!); // move the last element to the front
				return newArray;
			});
		}, 5000);
	};

	return (
		<div className="relative h-60 w-60 md:h-60 md:w-96">
			{cards?.map((card, index) => {
				return (
					<motion.div
						key={card.id}
						className={cn(
							"absolute flex h-60 w-60 flex-col justify-between rounded-3xl border border-neutral-200 bg-white p-4 shadow-xl shadow-black/[0.1] dark:border-white/[0.1] dark:bg-black dark:shadow-white/[0.05] md:h-60 md:w-96",
							card.className ? card.className : ""
						)}
						style={{
							transformOrigin: "top center",
						}}
						animate={{
							top: index * -CARD_OFFSET,
							scale: 1 - index * SCALE_FACTOR, // decrease scale for cards that are behind
							zIndex: cards.length - index, //  decrease z-index for the cards that are behind
						}}
					>
						{card.imageUrl ? (
							<Image
								src={card.imageUrl}
								alt="Card Image"
								className="h-full w-full rounded-3xl object-cover"
								width={384}
								height={256}
							/>
						) : (
							<>
								<div className="font-normal text-neutral-700 dark:text-neutral-200">
									{card.content}
								</div>
								<div>
									<p className="font-medium text-neutral-500 dark:text-white">
										{card.name}
									</p>
									<p className="font-normal text-neutral-400 dark:text-neutral-200">
										{card.designation}
									</p>
								</div>
							</>
						)}
					</motion.div>
				);
			})}
		</div>
	);
};
